@@ -1,10 +1,11 @@
+
 /*
- * $Id: send-announce.c,v 1.10.2.9 1996/07/08 18:31:05 wessels Exp $
+ * $Id: send-announce.c,v 1.26 1996/11/14 18:38:47 wessels Exp $
  *
  * DEBUG: section 27    Cache Announcer
  * AUTHOR: Duane Wessels
  *
- * SQUID Internet Object Cache  http://www.nlanr.net/Squid/
+ * SQUID Internet Object Cache  http://squid.nlanr.net/Squid/
  * --------------------------------------------------------
  *
  *  Squid is the result of efforts by numerous individuals from the
@@ -30,23 +31,24 @@
 
 #include "squid.h"
 
-void send_announce()
+void
+send_announce(void *unused)
 {
-    static char tbuf[256];
-    static char sndbuf[BUFSIZ];
+    LOCAL_ARRAY(char, tbuf, 256);
+    LOCAL_ARRAY(char, sndbuf, BUFSIZ);
     icpUdpData *qdata = NULL;
-    struct hostent *hp = NULL;
-    char *host = NULL;
+    const ipcache_addrs *ia = NULL;
+    char *host = Config.Announce.host;
     char *file = NULL;
-    u_short port;
+    u_short port = Config.Announce.port;
     int fd;
     int l;
     int n;
 
-    host = getAnnounceHost();
-    port = getAnnouncePort();
-
-    if ((hp = ipcache_gethostbyname(host, IP_BLOCKING_LOOKUP)) == NULL) {
+    if (!Config.Announce.on)
+	return;
+    eventAdd("send_announce", send_announce, NULL, Config.Announce.rate);
+    if ((ia = ipcache_gethostbyname(host, IP_BLOCKING_LOOKUP)) == NULL) {
 	debug(27, 1, "send_announce: Unknown host '%s'\n", host);
 	return;
     }
@@ -55,11 +57,11 @@ void send_announce()
     strcat(sndbuf, tbuf);
     sprintf(tbuf, "Running on %s %d %d\n",
 	getMyHostname(),
-	getHttpPortNum(),
-	getIcpPortNum());
+	Config.Port.http,
+	Config.Port.icp);
     strcat(sndbuf, tbuf);
-    if (getAdminEmail()) {
-	sprintf(tbuf, "cache_admin: %s\n", getAdminEmail());
+    if (Config.adminEmail) {
+	sprintf(tbuf, "cache_admin: %s\n", Config.adminEmail);
 	strcat(sndbuf, tbuf);
     }
     sprintf(tbuf, "generated %d [%s]\n",
@@ -68,13 +70,13 @@ void send_announce()
     strcat(sndbuf, tbuf);
     l = strlen(sndbuf);
 
-    if ((file = getAnnounceFile())) {
+    if ((file = Config.Announce.file)) {
 	fd = file_open(file, NULL, O_RDONLY);
 	if (fd > -1 && (n = read(fd, sndbuf + l, BUFSIZ - l - 1)) > 0) {
 	    l += n;
 	    sndbuf[l] = '\0';
 	} else {
-	    debug(27, 1, "send_announce: %s: %s\n", file, xstrerror());
+	    debug(50, 1, "send_announce: %s: %s\n", file, xstrerror());
 	}
     }
     qdata = xcalloc(1, sizeof(icpUdpData));
@@ -82,10 +84,10 @@ void send_announce()
     qdata->len = strlen(sndbuf) + 1;
     qdata->address.sin_family = AF_INET;
     qdata->address.sin_port = htons(port);
-    xmemcpy(&qdata->address.sin_addr, hp->h_addr_list[0], hp->h_length);
+    qdata->address.sin_addr = ia->in_addrs[0];
     AppendUdp(qdata);
-    comm_set_select_handler(theOutIcpConnection,
+    commSetSelect(theOutIcpConnection,
 	COMM_SELECT_WRITE,
 	(PF) icpUdpReply,
-	(void *) qdata);
+	(void *) qdata, 0);
 }
