@@ -1,9 +1,9 @@
 /*
- * $Id: url.h,v 1.11.2.12 1996/09/12 22:34:24 wessels Exp $
+ * $Id: url.h,v 1.36 1996/11/28 07:27:24 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
- * SQUID Internet Object Cache  http://www.nlanr.net/Squid/
+ * SQUID Internet Object Cache  http://squid.nlanr.net/Squid/
  * --------------------------------------------------------
  *
  *  Squid is the result of efforts by numerous individuals from the
@@ -33,16 +33,17 @@
 #define MAX_URL  4096
 #define MAX_LOGIN_SZ  128
 
-typedef enum {
-    METHOD_NONE,
-    METHOD_GET,
-    METHOD_POST,
-    METHOD_PUT,
-    METHOD_HEAD,
-    METHOD_CONNECT
-} method_t;
+enum {
+    METHOD_NONE,		/* 000 */
+    METHOD_GET,			/* 001 */
+    METHOD_POST,		/* 010 */
+    METHOD_PUT,			/* 011 */
+    METHOD_HEAD,		/* 100 */
+    METHOD_CONNECT		/* 101 */
+};
+typedef unsigned int method_t;
 
-extern char *RequestMethodStr[];
+extern const char *RequestMethodStr[];
 
 typedef enum {
     PROTO_NONE,
@@ -54,41 +55,43 @@ typedef enum {
     PROTO_MAX
 } protocol_t;
 
-extern char *ProtocolStr[];
-
 struct _request {
     method_t method;
     protocol_t protocol;
-    char login[MAX_LOGIN_SZ + 1];
+    char login[MAX_LOGIN_SZ];
     char host[SQUIDHOSTNAMELEN + 1];
-    int port;
-    char urlpath[MAX_URL + 1];
+    u_short port;
+    char urlpath[MAX_URL];
     int link_count;		/* free when zero */
-    hier_code hierarchy_code;
+    struct _hierarchyLogData hierarchy;
     int flags;
+    time_t max_age;
+    float http_ver;
 };
 
-/* bitfields for the flags member */
-#define		REQ_HTML	0x01
-#define		REQ_NOCACHE	0x02
-#define		REQ_IMS		0x04
-#define		REQ_AUTH	0x08
-#define		REQ_CACHABLE	0x10
-#define 	REQ_ACCEL	0x20
-#define 	REQ_HIERARCHICAL 0x40
-#define 	REQ_LOOPDETECT  0x80
-
 extern char *url_convert_hex _PARAMS((char *org_url, int allocate));
-extern char *url_escape _PARAMS((char *url));
-extern protocol_t urlParseProtocol _PARAMS((char *));
-extern method_t urlParseMethod _PARAMS((char *));
-extern int urlDefaultPort _PARAMS((protocol_t));
+extern char *url_escape _PARAMS((const char *url));
+extern protocol_t urlParseProtocol _PARAMS((const char *));
+extern method_t urlParseMethod _PARAMS((const char *));
 extern void urlInitialize _PARAMS((void));
 extern request_t *urlParse _PARAMS((method_t, char *));
-extern char *urlCanonical _PARAMS((request_t *, char *));
+extern char *urlCanonical _PARAMS((const request_t *, char *));
 extern request_t *requestLink _PARAMS((request_t *));
 extern void requestUnlink _PARAMS((request_t *));
-extern int matchDomainName _PARAMS((char *d, char *h));
-extern int urlCheckRequest _PARAMS((request_t *));
+extern int matchDomainName _PARAMS((const char *d, const char *h));
+extern int urlCheckRequest _PARAMS((const request_t *));
+
+/* bitfields for the flags member */
+#define REQ_UNUSED1		0x01
+#define REQ_NOCACHE		0x02
+#define REQ_IMS			0x04
+#define REQ_AUTH		0x08
+#define REQ_CACHABLE		0x10
+#define REQ_UNUSED2		0x20
+#define REQ_HIERARCHICAL	0x40
+#define REQ_LOOPDETECT		0x80
+#define REQ_PROXY_KEEPALIVE	0x100
+#define REQ_PROXYING		0x200
+#define REQ_REFRESH		0x400
 
 #endif /* _URL_HEADER_ */
